// -*- mode: cpp; mode: fold -*-
// Description								/*{{{*/
// $Id: gpmdev.h,v 1.2 1998/08/27 04:09:44 jgg Exp $
/* ######################################################################

   GPMDev - GPM based mouse input handler
   
   The GPM mouse handler accepts mouse input from the Linux GPM driver
   and translates it into our internal event structure. This is 
   automatically initialized by the various linux text interfaces if they 
   feel it is appropriate.

   ###################################################################### */
									/*}}}*/
// Header section: deity
#ifndef DEITY_GPMDEV_H
#define DEITY_GPMDEV_H

#ifdef __GNUG__
#pragma interface "deity/gpmdev.h"
#endif  

#include <deity/selectloop.h>

class Widget;
class GPMFd : public SelectLoop::Fd
{
   protected:
   
   // Widget to use as the top of the widget tree
   Widget *Root;
   Widget *LastHit;
   unsigned long OldButtons;
   
   virtual bool Read(SelectLoop &Owner);

   public:
   
   GPMFd(Widget *Root);
   virtual ~GPMFd();
};

#endif
